(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/forms'), require('prosemirror-state'), require('prosemirror-view'), require('ngx-editor/plugins'), require('prosemirror-model'), require('prosemirror-schema-list')) :
    typeof define === 'function' && define.amd ? define('ngx-editor', ['exports', '@angular/core', '@angular/forms', 'prosemirror-state', 'prosemirror-view', 'ngx-editor/plugins', 'prosemirror-model', 'prosemirror-schema-list'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-editor'] = {}, global.ng.core, global.ng.forms, global.prosemirrorState, global.prosemirrorView, global['ngx-editor'].plugins, global.prosemirrorModel, global.prosemirrorSchemaList));
}(this, (function (exports, i0, forms, prosemirrorState, prosemirrorView, plugins, prosemirrorModel, sl) { 'use strict';

    var doc = {
        content: 'block+'
    };
    // :: NodeSpec The text node.
    var text = {
        group: 'inline'
    };
    // :: NodeSpec A plain paragraph textblock. Represented in the DOM
    // as a `<p>` element.
    var paragraph = {
        content: 'inline*',
        group: 'block',
        parseDOM: [{ tag: 'p' }],
        toDOM: function () {
            return ['p', 0];
        }
    };
    // :: NodeSpec A blockquote (`<blockquote>`) wrapping one or more blocks.
    var blockquote = {
        content: 'block+',
        group: 'block',
        defining: true,
        parseDOM: [{ tag: 'blockquote' }],
        toDOM: function () {
            return ['blockquote', 0];
        }
    };
    // :: NodeSpec A horizontal rule (`<hr>`).
    var horizontalRule = {
        group: 'block',
        parseDOM: [{ tag: 'hr' }],
        toDOM: function () {
            return ['hr'];
        }
    };
    // :: NodeSpec A heading textblock, with a `level` attribute that
    // should hold the number 1 to 6. Parsed and serialized as `<h1>` to
    // `<h6>` elements.
    var heading = {
        attrs: { level: { default: 1 } },
        content: 'inline*',
        group: 'block',
        defining: true,
        parseDOM: [{ tag: 'h1', attrs: { level: 1 } },
            { tag: 'h2', attrs: { level: 2 } },
            { tag: 'h3', attrs: { level: 3 } },
            { tag: 'h4', attrs: { level: 4 } },
            { tag: 'h5', attrs: { level: 5 } },
            { tag: 'h6', attrs: { level: 6 } }],
        toDOM: function (node) {
            return ['h' + node.attrs.level, 0];
        }
    };
    // :: NodeSpec A code listing. Disallows marks or non-text inline
    // nodes by default. Represented as a `<pre>` element with a
    // `<code>` element inside of it.
    var codeBlock = {
        content: 'text*',
        marks: '',
        group: 'block',
        code: true,
        defining: true,
        parseDOM: [{ tag: 'pre', preserveWhitespace: 'full' }],
        toDOM: function () {
            return ['pre', ['code', 0]];
        }
    };
    // :: NodeSpec A hard line break, represented in the DOM as `<br>`.
    var hardBreak = {
        inline: true,
        group: 'inline',
        selectable: false,
        parseDOM: [{ tag: 'br' }],
        toDOM: function () {
            return ['br'];
        }
    };
    // :: NodeSpec An inline image (`<img>`) node. Supports `src`,
    // `alt`, and `href` attributes. The latter two default to the empty
    // string.
    var image = {
        inline: true,
        attrs: {
            src: {},
            alt: { default: null },
            title: { default: null },
            width: { default: null }
        },
        group: 'inline',
        draggable: true,
        parseDOM: [
            {
                tag: 'img[src]',
                getAttrs: function (dom) {
                    return {
                        src: dom.getAttribute('src'),
                        title: dom.getAttribute('title'),
                        alt: dom.getAttribute('alt'),
                        width: dom.getAttribute('width')
                    };
                }
            }
        ],
        toDOM: function (node) {
            var _a = node.attrs, src = _a.src, alt = _a.alt, title = _a.title, width = _a.width;
            return ['img', { src: src, alt: alt, title: title, width: width }];
        }
    };
    var listItem = Object.assign(Object.assign({}, sl.listItem), { content: 'paragraph block*' });
    var orderedList = Object.assign(Object.assign({}, sl.orderedList), { content: 'list_item+', group: 'block' });
    var bulletList = Object.assign(Object.assign({}, sl.bulletList), { content: 'list_item+', group: 'block' });
    var nodes = {
        doc: doc,
        text: text,
        paragraph: paragraph,
        blockquote: blockquote,
        horizontal_rule: horizontalRule,
        heading: heading,
        hard_break: hardBreak,
        code_block: codeBlock,
        image: image,
        list_item: listItem,
        ordered_list: orderedList,
        bullet_list: bulletList
    };

    // :: MarkSpec A link. Has `href` and `title` attributes. `title`
    // defaults to the empty string. Rendered and parsed as an `<a>`
    // element.
    var link = {
        attrs: {
            href: {},
            title: { default: null },
            default: { default: '_blank' }
        },
        inclusive: false,
        parseDOM: [
            {
                tag: 'a[href]',
                getAttrs: function (dom) {
                    return {
                        href: dom.getAttribute('href'),
                        title: dom.getAttribute('title')
                    };
                }
            }
        ],
        toDOM: function (node) {
            var _a = node.attrs, href = _a.href, title = _a.title;
            return ['a', { href: href, title: title }, 0];
        }
    };
    // :: MarkSpec An emphasis mark. Rendered as an `<em>` element.
    // Has parse rules that also match `<i>` and `font-style: italic`.
    var em = {
        parseDOM: [
            { tag: 'i' },
            { tag: 'em' },
            { style: 'font-style=italic' }
        ],
        toDOM: function () {
            return ['em', 0];
        }
    };
    var ɵ0 = function (dom) {
        return dom.style.fontWeight !== 'normal' && null;
    }, ɵ1 = function (value) {
        return /^(bold(er)?|[5-9]\d{2,})$/.test(value) && null;
    };
    // :: MarkSpec A strong mark. Rendered as `<strong>`, parse rules
    // also match `<b>` and `font-weight: bold`.
    var strong = {
        parseDOM: [
            { tag: 'strong' },
            // This works around a Google Docs misbehavior where
            // pasted content will be inexplicably wrapped in `<b>`
            // tags with a font-weight normal.
            {
                tag: 'b',
                getAttrs: ɵ0,
            },
            {
                style: 'font-weight',
                getAttrs: ɵ1
            }
        ],
        toDOM: function () {
            return ['strong', 0];
        }
    };
    // :: MarkSpec Code font mark. Represented as a `<code>` element.
    var code = {
        parseDOM: [
            { tag: 'code' }
        ],
        toDOM: function () {
            return ['code', 0];
        }
    };
    var makrs = {
        link: link,
        em: em,
        strong: strong,
        code: code
    };

    var schema = new prosemirrorModel.Schema({
        marks: makrs,
        nodes: nodes
    });

    var NgxEditorServiceConfig = /** @class */ (function () {
        function NgxEditorServiceConfig() {
            this.plugins = [
                plugins.menu(),
                plugins.placeholder()
            ];
            this.nodeViews = {};
            this.schema = schema;
        }
        return NgxEditorServiceConfig;
    }());
    NgxEditorServiceConfig.ɵprov = i0.ɵɵdefineInjectable({ factory: function NgxEditorServiceConfig_Factory() { return new NgxEditorServiceConfig(); }, token: NgxEditorServiceConfig, providedIn: "root" });
    NgxEditorServiceConfig.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    var NgxEditorService = /** @class */ (function () {
        function NgxEditorService(config) {
            this.config = config;
        }
        return NgxEditorService;
    }());
    NgxEditorService.ɵprov = i0.ɵɵdefineInjectable({ factory: function NgxEditorService_Factory() { return new NgxEditorService(i0.ɵɵinject(NgxEditorServiceConfig, 8)); }, token: NgxEditorService, providedIn: "root" });
    NgxEditorService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    NgxEditorService.ctorParameters = function () { return [
        { type: NgxEditorServiceConfig, decorators: [{ type: i0.Optional }] }
    ]; };
    var defaultConfig = {
        plugins: [],
        nodeViews: {},
        schema: schema
    };
    function provideMyServiceOptions(config) {
        return Object.assign({}, defaultConfig, config);
    }

    var NgxEditorComponent = /** @class */ (function () {
        function NgxEditorComponent(ngxEditorService) {
            this.editorInitialized = false;
            this.config = ngxEditorService.config;
        }
        NgxEditorComponent.prototype.writeValue = function (value) {
            if (!this.editorInitialized) {
                return;
            }
            this.updateContent(value);
        };
        NgxEditorComponent.prototype.registerOnChange = function (fn) {
            this.onChange = fn;
        };
        NgxEditorComponent.prototype.registerOnTouched = function () { };
        NgxEditorComponent.prototype.parseDoc = function (contentJson) {
            if (!contentJson) {
                return null;
            }
            var schema = this.config.schema;
            return schema.nodeFromJSON(contentJson);
        };
        NgxEditorComponent.prototype.updateContent = function (value) {
            try {
                var doc = this.parseDoc(value);
                var state = this.view.state;
                // don't emit if both content is same
                if (doc !== null && state.doc.eq(doc)) {
                    return;
                }
                var tr = state.tr;
                tr.replaceWith(0, state.doc.content.size, doc);
                this.view.dispatch(tr);
            }
            catch (err) {
                console.error('Unable to update document.', err);
            }
        };
        NgxEditorComponent.prototype.handleTransactions = function (tr) {
            var state = this.view.state.applyTransaction(tr).state;
            this.view.updateState(state);
            if (tr.docChanged && this.onChange) {
                var json = state.doc.toJSON();
                this.onChange(json);
            }
        };
        NgxEditorComponent.prototype.createEditor = function () {
            var _a = this.config, schema = _a.schema, plugins = _a.plugins, nodeViews = _a.nodeViews;
            this.view = new prosemirrorView.EditorView(this.ngxEditor.nativeElement, {
                state: prosemirrorState.EditorState.create({
                    schema: schema,
                    plugins: plugins
                }),
                nodeViews: nodeViews,
                dispatchTransaction: this.handleTransactions.bind(this),
                attributes: {
                    class: 'NgxEditor__Content'
                },
            });
            this.editorInitialized = true;
        };
        NgxEditorComponent.prototype.ngOnInit = function () {
            this.createEditor();
        };
        NgxEditorComponent.prototype.ngOnDestroy = function () {
            this.view.destroy();
        };
        return NgxEditorComponent;
    }());
    NgxEditorComponent.decorators = [
        { type: i0.Component, args: [{
                    selector: 'ngx-editor',
                    template: "<div class=\"NgxEditor\" #ngxEditor></div>\n",
                    providers: [{
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: i0.forwardRef(function () { return NgxEditorComponent; }),
                            multi: true
                        }],
                    encapsulation: i0.ViewEncapsulation.None,
                    styles: [".NgxEditor{background:#fff;background-clip:padding-box;border:2px solid rgba(0,0,0,.2);border-radius:4px;color:#000;overflow:hidden;position:relative}.NgxEditor__MenuBar{border-bottom:1px solid #ddd;cursor:default;display:flex;height:1.85rem;padding:.2rem}.NgxEditor__MenuItem{align-items:center;border-radius:2px;display:flex;justify-content:center;position:relative}.NgxEditor__MenuItem:hover{background-color:#f1f1f1}.NgxEditor__MenuItem.NgxEditor__MenuItem--Icon{height:1.85rem;transition:.3s ease-in-out;width:1.85rem}.NgxEditor__MenuItem.NgxEditor__MenuItem--Icon+.NgxEditor__MenuItem--Icon{margin-left:2px}.NgxEditor__MenuItem .NgxEditor__MenuItem--IconContainer{display:flex}.NgxEditor__MenuItem.NgxEditor__MenuItem--Text{padding:0 .3rem}.NgxEditor__MenuItem.NgxEditor__MenuItem--Active{background-color:#e8f0fe}.NgxEditor__MenuItem.NgxEditor__MenuItem--Active.NgxEditor__MenuItem--Text{color:#1a73e8}.NgxEditor__MenuItem.NgxEditor__MenuItem--Active svg{fill:#1a73e8}.NgxEditor--Disabled{opacity:.5;pointer-events:none}.NgxEditor__Seperator{border-left:1px solid #ccc;margin:0 .3rem}.NgxEditor__Dropdown{align-items:center;display:flex;min-width:4rem;position:relative}.NgxEditor__Dropdown:hover{background-color:#f1f1f1}.NgxEditor__Dropdown .NgxEditor__Dropdown__Text{align-items:center;display:flex;padding:0 .3rem}.NgxEditor__Dropdown .NgxEditor__Dropdown__Text:after{border-bottom:0;border-left:.25rem solid transparent;border-right:.25rem solid transparent;border-top:.25rem solid;content:\"\";display:inline-block;margin-left:1.5rem;vertical-align:.25rem}.NgxEditor__Dropdown .NgxEditor__Dropdown__DropdownMenu{background-color:#fff;border-radius:4px;box-shadow:0 2px 6px 2px rgba(60,64,67,.15);display:none;left:0;position:absolute;top:calc(1.85rem + 2px);width:100%;z-index:10}.NgxEditor__Dropdown .NgxEditor__Dropdown__Item{color:inherit;padding:.5rem;white-space:nowrap}.NgxEditor__Dropdown .NgxEditor__Dropdown__Item:hover{background-color:#ececec}.NgxEditor__Dropdown.NgxEditor__Dropdown--Open,.NgxEditor__Dropdown.NgxEditor__Dropdown--Selected{background-color:#e8f0fe}.NgxEditor__Dropdown.NgxEditor__Dropdown--Open .NgxEditor__Dropdown__Text,.NgxEditor__Dropdown.NgxEditor__Dropdown--Selected .NgxEditor__Dropdown__Text{color:#1a73e8}.NgxEditor__Dropdown .NgxEditor__Dropdown--Active{background-color:#f1f1f1}.NgxEditor__Dropdown .NgxEditor__Dropdown--Active:hover{background-color:#e7e7e7}.NgxEditor__Dropdown.NgxEditor__Dropdown--Open .NgxEditor__Dropdown__DropdownMenu{display:block}.NgxEditor__Popup{background-color:#fff;border-radius:4px;box-shadow:0 2px 6px 2px rgba(60,64,67,.15);display:none;min-width:12rem;padding:8px;position:absolute;top:calc(1.85rem + 2px);z-index:10}.NgxEditor__Popup .NgxEditor__Popup--FormGroup{margin-bottom:8px}.NgxEditor__Popup .NgxEditor__Popup--FormGroup label{margin-bottom:3px}.NgxEditor__Popup .NgxEditor__Popup--FormGroup input[type=text],.NgxEditor__Popup .NgxEditor__Popup--FormGroup input[type=url]{padding:2px 4px}.NgxEditor__Popup .NgxEditor__Popup--Col{display:flex;flex-direction:column;position:relative}.NgxEditor__Popup .NgxEditor__Popup--Label{font-size:85%}.NgxEditor__Popup.NgxEditor__Popup--Open{display:block}.NgxEditor__Placeholder{color:#6c757d;opacity:1}.NgxEditor__Content{padding:.5rem;white-space:pre-wrap}.NgxEditor__Content p{margin:0 0 .7rem}.NgxEditor__Content blockquote{border-left:3px solid #ddd;margin-left:0;margin-right:0;padding-left:1rem}.NgxEditor__FloatingBubble{background:#fff;border:1px solid silver;border-radius:4px;display:flex;margin-bottom:.3rem;padding:.3rem;position:absolute;transform:translateX(-50%);z-index:20}.NgxEditor__FloatingBubble:after,.NgxEditor__FloatingBubble:before{border:solid transparent;border-width:5px 5px 0;content:\"\";height:0;left:50%;margin-left:-5px;position:absolute;width:0}.NgxEditor__FloatingBubble:before{border-top-color:silver;bottom:-6px}.NgxEditor__FloatingBubble:after{border-top-color:#fff;bottom:-4.5px}.NgxEditor__FloatingBubble a{display:inline-block;margin-left:2px;max-width:15rem;overflow:hidden;text-overflow:ellipsis}.NgxEditor__FloatingBubble .commands{display:flex;margin-left:.5rem}.NgxEditor__FloatingBubble .commands .command{border:none}.NgxEditor__FloatingBubble .commands .command:hover{text-decoration:underline}.NgxEditor__ImageWrapper{display:inline-block;line-height:0;padding:1px;position:relative}.NgxEditor__ImageWrapper.NgxEditor__Resizer--Active{border:1px solid #1a73e8;padding:0}.NgxEditor__ImageWrapper .NgxEditor__ResizeHandle{background-color:#1a73e8;border:1px solid #fff;bottom:-5px;cursor:nwse-resize;display:none;height:7px;position:absolute;right:-5px;width:7px}.ProseMirror{outline:none}"]
                },] }
    ];
    NgxEditorComponent.ctorParameters = function () { return [
        { type: NgxEditorService }
    ]; };
    NgxEditorComponent.propDecorators = {
        ngxEditor: [{ type: i0.ViewChild, args: ['ngxEditor', { static: true },] }]
    };

    var NGX_EDITOR_CONFIG_TOKEN = new i0.InjectionToken('NgxEditorConfig');
    var NgxEditorModule = /** @class */ (function () {
        function NgxEditorModule() {
        }
        NgxEditorModule.forRoot = function (config) {
            return {
                ngModule: NgxEditorModule,
                providers: [
                    {
                        provide: NGX_EDITOR_CONFIG_TOKEN,
                        useValue: config
                    },
                    {
                        provide: NgxEditorServiceConfig,
                        useFactory: provideMyServiceOptions,
                        deps: [NGX_EDITOR_CONFIG_TOKEN]
                    }
                ]
            };
        };
        return NgxEditorModule;
    }());
    NgxEditorModule.decorators = [
        { type: i0.NgModule, args: [{
                    declarations: [NgxEditorComponent],
                    exports: [NgxEditorComponent],
                },] }
    ];

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NgxEditorComponent = NgxEditorComponent;
    exports.NgxEditorModule = NgxEditorModule;
    exports.marks = makrs;
    exports.nodes = nodes;
    exports.schema = schema;
    exports.ɵa = NgxEditorServiceConfig;
    exports.ɵb = NgxEditorService;
    exports.ɵc = provideMyServiceOptions;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-editor.umd.js.map
